@@ -15,9 +15,11 @@ def identity(x: A) -> A:
 def mapping_get(data: Mapping[A, B], key: A) -> Maybe[B]:
     # this is better than data.get(...) because if None is a valid return value,
     # there's no way to know if the value is the value from the map or the deafult value
-    try:
+
+    # this is faster than try/except KeyError in initial testing
+    if key in data:
         return Just(data[key])
-    except KeyError:
+    else:
         return nothing
 
 
